/****************************************************************************
*Commande de porte de garage à un seul bouton. Un appui demande un mouvement*
*Une seconde solicitation arrête la porte ou inverse le mouvement après     *
* l'arrêt . Deux sorties sont prévues (voir autres options). J'ai volontair-*
*-ment utilisé la sortie 12 car la 14 est active pendant le boot ou sur     * 
* apparition de la tension d'alimentation                                   *
*https://amazing-vacuum-tubes.com                                           *
****************************************************************************/

//Appel des librairies utilisées 
#include "WiFi.h"
#include <ESPAsyncWebServer.h>

//Déclaration des sorties pour les relais
const int output12 = 12;
const int output14 = 14;

//Saisie des identifiant de la box, reseau et clé 
const char* ssid = "XxxxxxxxxxXX";
const char* password = "ZZZZZZZzzzzzzZZZZZZZZ";

//Créer une entrée asynchrone serveur réseau sur le port 80
AsyncWebServer server(80);

//La porte doit bouger... ou pas
boolean movDoor = false;

//Génere la page html d'accueil, le titre et le fond
const char index_html[] PROGMEM = R"rawliteral(
<!DOCTYPE HTML><html>
<head>
<title>ESP32-Garage</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <style>
    html {font-family: Arial; display: inline-block; text-align: center;cursor: grab;}
    p {  font-size: 1.2rem;}
    body {  margin: 0;}
    .topnav { overflow: hidden; background-color: #4CAF50; color: white; font-size: 1.8rem; }
    .button { padding: 15px 50px; font-size: 24px;text-align: center; outline: none; color: #fff; background-color: #8d0f8b; border: inset;
    border-top-right-radius: 80px 80px;cursor: grab;}
  </style>
</head>
<body>
  <div class="topnav">
    <h3>Commande Porte de Garage</h3>
    <p>Un appui sur le bouton pour la commande </p>
    <p>
      <div class="button">
      <button onclick="cmdePorte()">PORTE OK</button>
    </p>
  </div>
</body>
<script>
  function cmdePorte() {
    var cde = new XMLHttpRequest();
    cde.open('GET', "/comande", true);
    cde.send();
  }
</script>
</html>)rawliteral";

void setup() {
  //Connexion au Wi-Fi
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
  }

  //Route pour la racine et la page Web
  server.on("/", HTTP_GET, [](AsyncWebServerRequest * request) {
    request->send_P(200, "text/html", index_html);
  });
  server.on("/comande", HTTP_GET, [](AsyncWebServerRequest * request) {
    movDoor = true;
  });

  //Démarage du serveur
  server.begin();

  //DDR des sorties pour la commande des relais
  pinMode(output12,OUTPUT);
  pinMode(output14,OUTPUT);
  digitalWrite(output12,LOW);
  digitalWrite(output14,LOW);   
}

void loop() {
  // Si le bouton "Porte OK" est activé, on demande un mouvement de porte
  if (movDoor) {
    digitalWrite(output12,HIGH);
    delay (1500);
    digitalWrite(output12,LOW);
    movDoor = false;    
  }
}



