/*************************************************************************
*Commande de porte de garage ou volets motorisés en Wi-Fi par smartphone *
*avec 3 boutons (montée-descente-stop). Le caption de chaque bouton rens-*
*-eigne sur l'état logique le statu de la porte, en considérant que la   *
* porte de garage ou le volet asservi est auto géré ...                  *
* https://amazing-vacuum-tubes.com                                       *
*************************************************************************/

// Charge la bibliothèque du Wi-Fi
#include <WiFi.h>

// Ici, les identifiants réseau
const char* ssid = "XXXXXXXXXXxxxxx";
const char* password = "zzzzzzZZZZZzzzzzZZZZ";

// Attribut le port 80 sur le serveur
WiFiServer server(80);

// Variable de demande HTTP
String header;

// Variables auxiliaires des etats de sorties
String output14State = "off";
String output12State = "off";
String output13State = "off";

// Affectation des sorties
const int output14 = 14;
const int output12 = 12;

// Unité de temps
unsigned long currentTime = millis();
// Temps prévus
unsigned long previousTime = 0; 
// Temps alloués (example: 2000ms = 2s)
const long timeoutTime = 2000;


void setup() {
  // DDR des sorties
  pinMode(output14, OUTPUT);
  pinMode(output12, OUTPUT);

  // Mise à l'état bas
  digitalWrite(output14, LOW);
  digitalWrite(output12, LOW);

  // Connexion au Wi-Fi
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
  }
  server.begin();
}

void loop(){
  WiFiClient client = server.available();   
  if (client) {                             // Si c'est un nouveau clent,
    currentTime = millis();
    previousTime = currentTime;
    String currentLine = "";                // crée une chaine pour la reconnaissance 
    while (client.connected() && currentTime - previousTime <= timeoutTime) {  // jusqu'à ce que le client soi connecté
      currentTime = millis();
      if (client.available()) {             // Si c'est un client connu, lit le byte affecté à ce client
        char c = client.read();             
        header += c;
        if (c == '\n') {                    
           if (currentLine.length() == 0) {
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println("Connection: close");
            client.println();
            
            // Mise à "on" ou "off" des états de sortie et des sorties
            if (header.indexOf("GET /14/on") >= 0) {
              Serial.println("GPIO 14 on");
              output14State = "on";
              output12State = "off";
              output13State = "off";
              digitalWrite(output14, HIGH);
              digitalWrite(output12, LOW);
            } else if (header.indexOf("GET /14/off") >= 0) {
              Serial.println("GPIO 14 off");
              output14State = "off";
              digitalWrite(output14, LOW);
             }else if (header.indexOf("GET /13/on") >= 0) {
              Serial.println("GPIO 13 on");
              output13State = "on";
              output12State = "off";
              output14State = "off";
              digitalWrite(output12, LOW);
              digitalWrite(output14, LOW);
            } else if (header.indexOf("GET /13/off") >= 0) {
              Serial.println("GPIO 13 off");
              output13State = "off";
            } else if (header.indexOf("GET /12/on") >= 0) {
              Serial.println("GPIO 12 on");
              output14State = "off";
              output12State = "on";
              output13State = "off";
              digitalWrite(output12, HIGH);
              digitalWrite(output14, LOW);
            } else if (header.indexOf("GET /12/off") >= 0) {
              Serial.println("GPIO 12 off");
              output12State = "off";
              digitalWrite(output12, LOW);
            }
            
            // Génération de la page HTML sue le web
            client.println("<!DOCTYPE html><html>");
            client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
            client.println("<link rel=\"icon\" href=\"data:,\">");
            client.println("<style>html { font-family: Helvetica; display: inline-block; margin: 0px auto; text-align: center;}");
            client.println(".button { background-color: #4CAF50; border: none; color: white; padding: 16px 40px;");
            client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}");
            client.println(".button2 {background-color: #555555;}</style></head>");
            
            // Tête de page Web
            client.println("<body><h1>Commande Garage & Volet</h1>");
            
          
            // Affichage de l'état, et le ON/OFF du bouton pour GPIO 14  
            client.println("<p>Ouverture " + output14State + "</p>");
            // Si la sortie 14 est off, on affiche "-UP-"sur le bouton       
            if (output14State=="off") {
              client.println("<p><a href=\"/14/on\"><button class=\"button\">-UP-</button></a></p>");
            } else {
              client.println("<p><a href=\"/14/off\"><button class=\"button button2\">UP-OK</button></a></p>");
            }

            // Affichage de l'état, et le ON/OFF du bouton pour GPIO 13  
            client.println("<p>Stop - Etat " + output13State + "</p>");
            // Si la sortie 13 est off, on affiche "STOP"sur le bouton       
            if (output13State=="off") {
              client.println("<p><a href=\"/13/on\"><button class=\"button\">STOP</button></a></p>");
            } else {
              client.println("<p><a href=\"/13/off\"><button class=\"button button2\">STOP-OK</button></a></p>");
            }

            // Affichage de l'état, et le ON/OFF du bouton pour GPIO 12  
            client.println("<p>Fermeture " + output12State + "</p>");
            // // Si la sortie 12 est off, on affiche "DWN-"sur le bouton       
            if (output12State=="off") {
              client.println("<p><a href=\"/12/on\"><button class=\"button\">DWN-</button></a></p>");
            } else {
              client.println("<p><a href=\"/12/off\"><button class=\"button button2\">DWN-OK</button></a></p>");
            }

            client.println("</body></html>");
            
            client.println();
            // Pas d'arrêt pendant la boucle
            break;
          } else { // si l'on a besoin d'un nouvel état
            currentLine = "";
          }
        } else if (c != '\r') {  
          currentLine += c; 
        }
      }
    }
    // Efface la variable
    header = "";
    // Ferme la connexion
    client.stop();

  }
}
